Library API
===========

The main objects are the :class:`~can.Bus` and the :class:`~can.Message`.
A form of CAN interface is also required.

.. hint::

    Check the backend specific documentation for any implementation specific details.


.. toctree::
   :maxdepth: 1

   bus
   message
   listeners
   asyncio
   bcm
   errors
   bit_timing
   utils
   internal-api


